{% extends "base.html" %}
{% block content %}

        <form action="" method="POST" name="form">
            <div class="col-md-4 col-md-offset-4">
                {{ form.hidden_tag() }}
                <div class="form-group">
                    <label class="control-label" for="username">Username</label>
                    {{ form.username }}
                </div>
                <div class="form-group">
                    <label class="control-label" for="password">Password</label>
                    {{ form.password }}
                </div>
                <button class="btn btn-default" type="submit">Submit</button>
            </div>
        </form>

{% endblock %}
