{% extends 'admin/model/edit.html' %}
{% import 'admin/quokka/macros.html' as quokka_macros with context %}

{% block tail %}
    {{ super() }}
    <script>
    $(function() {

    // $("#category").select2({
    //         // TODO: read from db
    //         tags: ['general', 'news', 'python'],
    //         tokenSeparators: [",", " "],
    //         // maximumSelectionLength: 2,
    //         // ajax: {
    //         //     url: '/quokka/ajax/categories',
    //         //     dataType: 'json',
    //         //     delay: 250,
    //         //     results: function (data) {
    //         //         return {
    //         //             results: $.map(data, function (item) {
    //         //                 return {
    //         //                     text: item.text,
    //         //                     id: item.id
    //         //                 }
    //         //             })
    //         //         };
    //         //     },
    //         //     cache: false
    //         // },
    //         // minimumInputLength: 2,
    //         // maximumSelectionLength: 6
    //     });

    });
    </script>
    <link href="https://gitcdn.github.io/bootstrap-toggle/2.2.2/css/bootstrap-toggle.min.css" rel="stylesheet">
    <script src="https://gitcdn.github.io/bootstrap-toggle/2.2.2/js/bootstrap-toggle.min.js"></script>

{% endblock %}
