#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['quokka', 'quokka.admin', 'quokka.core', 'quokka.utils']

package_data = \
{'': ['*'],
 'quokka': ['translations/*',
            'translations/zh_CN/*',
            'translations/zh_CN/LC_MESSAGES/*',
            'babel/*',
            'templates/*',
            'templates/admin/*',
            'templates/admin/quokka/*',
            'templates/errors/*',
            'project_template/*',
            'project_template/databases/*',
            'project_template/uploads/*',
            'project_template/themes/*',
            'project_template/themes/pure/*',
            'project_template/themes/pure/templates/*',
            'project_template/themes/Flex/*',
            'project_template/themes/Flex/static/*',
            'project_template/themes/Flex/static/stylesheet/*',
            'project_template/themes/Flex/static/img/*',
            'project_template/themes/Flex/static/pygments/*',
            'project_template/themes/Flex/static/font-awesome/*',
            'project_template/themes/Flex/static/font-awesome/fonts/*',
            'project_template/themes/Flex/static/font-awesome/css/*',
            'project_template/themes/Flex/translations/*',
            'project_template/themes/Flex/translations/nl_NL/*',
            'project_template/themes/Flex/translations/nl_NL/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/ru/*',
            'project_template/themes/Flex/translations/ru/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/zh_CN/*',
            'project_template/themes/Flex/translations/zh_CN/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/pt_BR/*',
            'project_template/themes/Flex/translations/pt_BR/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/fr/*',
            'project_template/themes/Flex/translations/fr/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/en/*',
            'project_template/themes/Flex/translations/en/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/es/*',
            'project_template/themes/Flex/translations/es/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/tr_TR/*',
            'project_template/themes/Flex/translations/tr_TR/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/de/*',
            'project_template/themes/Flex/translations/de/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/fa_IR/*',
            'project_template/themes/Flex/translations/fa_IR/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/et/*',
            'project_template/themes/Flex/translations/et/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/pl_PL/*',
            'project_template/themes/Flex/translations/pl_PL/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/it/*',
            'project_template/themes/Flex/translations/it/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/es_ES/*',
            'project_template/themes/Flex/translations/es_ES/LC_MESSAGES/*',
            'project_template/themes/Flex/translations/hu_HU/*',
            'project_template/themes/Flex/translations/hu_HU/LC_MESSAGES/*',
            'project_template/themes/Flex/templates/*',
            'project_template/themes/Flex/templates/partial/*',
            'project_template/themes/Flex/tests/*',
            'project_template/themes/Flex/tests/content/*',
            'project_template/themes/Flex/tests/content/stuff/*',
            'project_template/themes/Flex/tests/content/dev/*',
            'project_template/themes/Flex/tests/content/pages/*',
            'project_template/themes/Flex/pygments/*',
            'project_template/static_build/*']}

install_requires = \
['flask',
 'import_string',
 'flask_admin',
 'wtforms_components',
 'pymongo==2.4.1',
 'tinymongo',
 'tinydb_serialization',
 'manage',
 'dynaconf',
 'quokka_themes',
 'quokka_flask_htmlbuilder',
 'awesome_slugify',
 'flask_babelex',
 'flask_gravatar',
 'flask_mistune',
 'flask_simplelogin',
 'frozen_flask',
 'pillow',
 'pyrss2gen',
 'requests',
 'tablib',
 'flask_security']

entry_points = \
{'console_scripts': ['quokka = quokka.cli:main']}

setup(name='quokka',
      version='0.3.0',
      description='Quokka CMS!',
      author='Bruno Rocha',
      author_email='rochacbruno@gmail.com',
      url='https://github.com/rochacbruno/quokka',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
